@@ -16,9 +16,11 @@
 #' }
 #'
 #' @examples
+#' \dontrun{
 #' library(rstanarm)
 #' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
 #' effective_sample(model)
+#' }
 #' @export
 effective_sample <- function(model, ...) {
   UseMethod("effective_sample")
@@ -83,6 +85,35 @@ effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"
 
 
 
+#' @export
+effective_sample.stanfit <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+  # check arguments
+  effects <- match.arg(effects)
+
+  pars <-
+    insight::get_parameters(
+      model,
+      effects = effects,
+      parameters = parameters
+    )
+
+  if (!requireNamespace("rstan", quietly = TRUE)) {
+    stop("Package 'rstan' required for this function to work. Please install it.")
+  }
+
+  s <- as.data.frame(rstan::summary(model)$summary)
+  s <- s[rownames(s) %in% colnames(pars), ]
+
+  data.frame(
+    Parameter = rownames(s),
+    ESS = s[["n_eff"]],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+}
+
+
+
 #' @rdname effective_sample
 #' @export
 effective_sample.MCMCglmm <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
