@@ -97,6 +97,12 @@ eti.bcplm <- function(x, ci = .89, verbose = TRUE, ...) {
 }
 
 
+#' @rdname eti
+#' @export
+eti.bayesQR <- eti.bcplm
+
+
+
 
 #' @rdname eti
 #' @export
@@ -124,10 +130,7 @@ eti.sim <- function(x, ci = .89, parameters = NULL, verbose = TRUE, ...) {
 #' @rdname eti
 #' @export
 eti.emmGrid <- function(x, ci = .89, verbose = TRUE, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  xdf <- .clean_emmeans_draws(x)
 
   dat <- .compute_interval_dataframe(x = xdf, ci = ci, verbose = verbose, fun = "eti")
   attr(dat, "object_name") <- .safe_deparse(substitute(x))
@@ -152,6 +155,11 @@ eti.stanreg <- function(x, ci = .89, effects = c("fixed", "random", "all"),
 }
 
 
+#' @export
+eti.stanfit <- eti.stanreg
+
+
+
 #' @rdname eti
 #' @export
 eti.brmsfit <- function(x, ci = .89, effects = c("fixed", "random", "all"),
@@ -171,6 +179,7 @@ eti.brmsfit <- function(x, ci = .89, effects = c("fixed", "random", "all"),
 }
 
 
+
 #' @rdname eti
 #' @export
 eti.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
