@@ -20,7 +20,7 @@
 #' @param verbose Toggle off warnings.
 #' @param ... Currently not used.
 #'
-#'
+#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @details Unlike equal-tailed intervals (see \code{eti()}) that typically exclude 2.5\%
 #' from each tail of the distribution and always include the median, the HDI is
@@ -84,7 +84,6 @@
 #' hdi(bf)
 #' hdi(bf, ci = c(.80, .90, .95))
 #' }
-#'
 #' @author Credits go to \href{https://rdrr.io/cran/ggdistribute/src/R/stats.R}{ggdistribute} and \href{https://github.com/mikemeredith/HDInterval}{HDInterval}.
 #'
 #' @references \itemize{
@@ -122,6 +121,9 @@ hdi.data.frame <- function(x, ci = .89, verbose = TRUE, ...) {
 
 
 
+
+
+
 #' @rdname hdi
 #' @export
 hdi.MCMCglmm <- function(x, ci = .89, verbose = TRUE, ...) {
@@ -153,6 +155,10 @@ hdi.bcplm <- function(x, ci = .89, verbose = TRUE, ...) {
 }
 
 
+#' @rdname hdi
+#' @export
+hdi.bayesQR <- hdi.bcplm
+
 
 #' @rdname hdi
 #' @export
@@ -180,10 +186,7 @@ hdi.sim <- function(x, ci = .89, parameters = NULL, verbose = TRUE, ...) {
 #' @rdname hdi
 #' @export
 hdi.emmGrid <- function(x, ci = .89, verbose = TRUE, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  xdf <- .clean_emmeans_draws(x)
   out <- hdi(xdf, ci = ci, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -207,6 +210,9 @@ hdi.stanreg <- function(x, ci = .89, effects = c("fixed", "random", "all"), para
   out
 }
 
+#' @export
+hdi.stanfit <- hdi.stanreg
+
 
 
 #' @rdname hdi
@@ -226,6 +232,7 @@ hdi.brmsfit <- function(x, ci = .89, effects = c("fixed", "random", "all"), comp
 }
 
 
+
 #' @rdname hdi
 #' @export
 hdi.BFBayesFactor <- function(x, ci = .89, verbose = TRUE, ...) {
