@@ -61,7 +61,12 @@ map_estimate.numeric <- function(x, precision = 2^10, method = "kernel", ...) {
 
 
 
-
+#' @rdname map_estimate
+#' @export
+map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
 
 
 
@@ -98,6 +103,10 @@ map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects
   )
 }
 
+#' @export
+map_estimate.stanfit <- map_estimate.stanreg
+
+
 #' @rdname map_estimate
 #' @export
 map_estimate.brmsfit <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
@@ -112,6 +121,23 @@ map_estimate.brmsfit <- function(x, precision = 2^10, method = "kernel", effects
 
 
 
+#' @rdname map_estimate
+#' @export
+map_estimate.data.frame <- function(x, precision = 2^10, method = "kernel", ...) {
+  .map_estimate_models(x, precision = precision, method = method)
+}
+
+
+
+
+#' @rdname map_estimate
+#' @export
+map_estimate.emmGrid <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- .clean_emmeans_draws(x)
+  .map_estimate_models(x, precision = precision, method = method)
+}
+
+
 #' @rdname as.numeric.p_direction
 #' @method as.numeric map_estimate
 #' @export
