@@ -62,6 +62,8 @@
 #'   \strong{Limitations:} A ROPE range needs to be arbitrarily defined. Sensitive to the scale (the unit) of the predictors. Not sensitive to highly significant effects.
 #' }
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @references \itemize{
 #' \item Cohen, J. (1988). Statistical power analysis for the behavioural sciences.
 #' \item Kruschke, J. K. (2010). What to believe: Bayesian methods for data analysis. Trends in cognitive sciences, 14(7), 293-300. \doi{10.1016/j.tics.2010.05.001}.
@@ -178,13 +180,12 @@ rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", v
   dat
 }
 
+
+
 #' @rdname rope
 #' @export
 rope.emmGrid <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package 'emmeans' required for this function to work. Please install it by running `install.packages('emmeans')`.")
-  }
-  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  xdf <- .clean_emmeans_draws(x)
 
   dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(dat, "object_name") <- .safe_deparse(substitute(x))
@@ -234,6 +235,17 @@ rope.bcplm <- function(x, range = "default", ci = .89, ci_method = "HDI", verbos
 
 
 
+#' @export
+rope.bayesQR <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+  out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
+  attr(out, "object_name") <- NULL
+  attr(out, "data") <- .safe_deparse(substitute(x))
+  out
+}
+
+
+
+
 #' @keywords internal
 .rope <- function(x, range = c(-0.1, 0.1), ci = .89, ci_method = "HDI", verbose = TRUE) {
   ci_bounds <- ci(x, ci = ci, method = ci_method, verbose = verbose)
@@ -294,6 +306,8 @@ rope.stanreg <- function(x, range = "default", ci = .89, ci_method = "HDI", effe
   out
 }
 
+#' @export
+rope.stanfit <- rope.stanreg
 
 
 #' @rdname rope
