@@ -2,8 +2,13 @@
 #' @importFrom insight find_parameters
 #' @keywords internal
 .check_multicollinearity <- function(model, method = "equivalence_test", threshold = 0.7, ...) {
-  valid_parameters <- insight::find_parameters(model, parameters = "^(?!(r_|sd_|prior_|cor_|b\\[))", flatten = TRUE)
-  dat <- as.data.frame(model, optional = FALSE)[, valid_parameters]
+  valid_parameters <- insight::find_parameters(model, parameters = "^(?!(r_|sd_|prior_|cor_|lp__|b\\[))", flatten = TRUE)
+
+  if (inherits(model, "stanfit")) {
+    dat <- insight::get_parameters(model)[, valid_parameters]
+  } else {
+    dat <- as.data.frame(model, optional = FALSE)[, valid_parameters]
+  }
   dat <- dat[, -1, drop = FALSE]
 
   if (ncol(dat) > 1) {
