@@ -1,6 +1,4 @@
-if (requireNamespace("rstanarm", quietly = TRUE)) {
-  context("ci")
-
+if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
   test_that("ci", {
     testthat::expect_equal(ci(distribution_normal(1000), ci = .90)$CI_low[1], -1.6361, tolerance = 0.02)
     testthat::expect_equal(nrow(ci(distribution_normal(1000), ci = c(.80, .90, .95))), 3, tolerance = 0.01)
