@@ -78,6 +78,7 @@ if (require("rstanarm") && require("emmeans")) {
   test_that("emmGrid bayesfactor_parameters", {
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
     set.seed(4)
     xsdbf <- bayesfactor_parameters(all_, prior = model)
     testthat::expect_equal(log(xsdbf$BF), c(-2.5756125848835, 1.69713280431204, -0.212277519930343), tolerance = .1)
@@ -90,6 +91,7 @@ if (require("rstanarm") && require("emmeans")) {
   test_that("emmGrid bayesfactor_restricted", {
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
     set.seed(4)
     hyps <- c("`1` < `2`", "`1` < 0")
     xrbf <- bayesfactor_restricted(em_, prior = model, hypothesis = hyps)
@@ -102,6 +104,7 @@ if (require("rstanarm") && require("emmeans")) {
   test_that("emmGrid si", {
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
     set.seed(4)
     xrsi <- si(em_, prior = model)
     testthat::expect_equal(xrsi$CI_low, c(-0.8479125,  0.5738828), tolerance = .1)
@@ -111,6 +114,7 @@ if (require("rstanarm") && require("emmeans")) {
   test_that("emmGrid describe_posterior", {
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
     set.seed(4)
     xpost <- describe_posterior(
       all_,
@@ -144,6 +148,7 @@ if (require("rstanarm") && require("emmeans")) {
   test_that("emmGrid bayesfactor_restricted2", {
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
 
     hyps <- c("a < b", "b < c")
     xrbf1 <- bayesfactor_restricted(bayes_sum, fit_bayes, hypothesis = hyps)
@@ -157,10 +162,40 @@ if (require("rstanarm") && require("emmeans")) {
     set.seed(333)
     testthat::skip_on_travis()
     testthat::skip_on_cran()
+    testthat::skip_on_ci()
 
     xsdbf1 <- bayesfactor_parameters(bayes_sum, prior = fit_bayes)
     xsdbf2 <- bayesfactor_parameters(bayes_sum, prior = bayes_sum_prior)
 
-    # testthat::expect_equal(log(xsdbf1$BF), log(xsdbf2$BF), tolerance = 0.1)
+    testthat::expect_equal(log(xsdbf1$BF), log(xsdbf2$BF), tolerance = 0.1)
+  })
+
+  test_that("emmGrid bayesfactor_parameters / describe w/ nonlinear models", {
+    testthat::skip_on_travis()
+    testthat::skip_on_cran()
+    testthat::skip_on_ci()
+    set.seed(333)
+
+    model <- stan_glm(vs ~ mpg,
+                      data = mtcars,
+                      family = "binomial",
+                      refresh = 0)
+
+    probs <- emmeans(model, "mpg", type = "resp")
+    link <- emmeans(model, "mpg")
+
+    bfp1 <- bayesfactor_parameters(probs, prior = model, null = 0.5)
+    bfp2 <- bayesfactor_parameters(link, prior = model, null = 0)
+
+    testthat::expect_equal(bfp1$BF, 0.083, tolerance = 0.01)
+    testthat::expect_equal(bfp2$BF, 0.049, tolerance = 0.01)
+    testthat::expect_error(bayesfactor_parameters(regrid(link), prior = model))
+
+    hdip1 <- hdi(probs, ci = 0.9)
+    hdip2 <- hdi(link, ci = 0.9)
+    testthat::expect_equal(hdip1$CI_low, 0.265, tolerance = 0.01)
+    testthat::expect_equal(hdip1$CI_high, 0.646, tolerance = 0.01)
+    testthat::expect_equal(hdip2$CI_low, -1.016, tolerance = 0.01)
+    testthat::expect_equal(hdip2$CI_high, 0.607, tolerance = 0.01)
   })
 }
\ No newline at end of file
