@@ -1,13 +1,5 @@
-if (requireNamespace("logspline", quietly = TRUE) &&
-    requireNamespace("KernSmooth", quietly = TRUE) &&
-    requireNamespace("mclust", quietly = TRUE)) {
-  context("estimate_density")
-
+if (require("logspline") && require("KernSmooth") && require("mclust")) {
   test_that("estimate_density", {
-    library(logspline)
-    library(KernSmooth)
-    library(mclust)
-
     set.seed(333)
     x <- distribution_normal(500, 1)
 
